@@ -1,7 +1,7 @@
 // -*- C++ -*-
 //
 // This file is part of HepMC
-// Copyright (C) 2014-2021 The HepMC collaboration (see AUTHORS for details)
+// Copyright (C) 2014-2023 The HepMC collaboration (see AUTHORS for details)
 //
 #ifndef HEPMC3_GENPARTICLE_H
 #define HEPMC3_GENPARTICLE_H
@@ -22,9 +22,6 @@
 
 namespace HepMC3 {
 
-/** Deprecated */
-using namespace std;
-
 class GenEvent;
 class Attribute;
 
@@ -37,30 +34,30 @@ class GenParticle : public std::enable_shared_from_this<GenParticle> {
 // Constructors
 //
 public:
-    /** @brief Default constructor */
+
+    /// @brief Default constructor
     GenParticle( const FourVector &momentum = FourVector::ZERO_VECTOR(), int pid = 0, int status = 0 );
 
-    /** @brief Constructor based on particle data */
+    /// @brief Constructor based on particle data
     GenParticle( const GenParticleData &data );
 
 //
 // Functions
 //
 public:
-    /** @brief Check if this particle belongs to an event */
-    bool in_event() const { return (bool)(m_event); }
+    /// @brief Check if this particle belongs to an event
+    bool in_event() const { return (bool) (m_event); }
 
-//
-// Accessors
-//
-public:
+    /// @brief Get the parent event
+    GenEvent* parent_event() { return m_event; }
+    /// @brief Get the parent event (const)
+    const GenEvent* parent_event() const { return m_event; }
+
+    /// @brief Get the particle ID number (*not* PDG ID)
+    int id() const { return m_id; }
 
-    GenEvent*              parent_event() { return m_event; } //!< Get parent event
-    const GenEvent*              parent_event() const { return m_event; } //!< Get parent event
-    int                    id()           const { return m_id;    } //!< Get particle id
     const GenParticleData& data()         const { return m_data;  } //!< Get particle data
 
-
     ConstGenVertexPtr production_vertex() const;        //!< Get production vertex (const version)
     ConstGenVertexPtr end_vertex() const;               //!< Get end vertex (const version)
 
@@ -102,12 +99,11 @@ public:
     void set_generated_mass(double m);             //!< Set generated mass
     void unset_generated_mass();                   //!< Declare that generated mass is not set
 
-    /** @brief Add an attribute to this particle
-     *
-     *  This will overwrite existing attribute if an attribute with
-     *  the same name is present. The attribute will be stored in the
-     *  parent_event(). @return false if there is no parent_event();
-     */
+    /// @brief Add an attribute to this particle
+    ///
+    ///  This will overwrite existing attribute if an attribute with
+    ///  the same name is present. The attribute will be stored in the
+    ///  parent_event(). @return false if there is no parent_event();
     bool add_attribute(const std::string& name, std::shared_ptr<Attribute> att);
 
     /// @brief Get list of names of attributes assigned to this particle
@@ -135,7 +131,6 @@ public:
     /// @deprecated Use set_pid() instead
     void set_pdg_id(const int& pidin) { set_pid(pidin); }
 
-
     /// @}
 //
 // Fields
@@ -151,6 +146,8 @@ private:
 
 } // namespace HepMC3
 
+
+
 #include "HepMC3/GenEvent.h"
 namespace HepMC3 {
 /// @brief Get attribute of type T
